<!--
(c) 2017-2019, ETH Zurich, Institut fuer Theoretische Physik
Author: Dominik Gresch <mail@greschd.ch>
-->


Utilities for creating, comparing and plotting bandstructures of materials.

Documentation: https://bands-inspect.greschd.ch

[![Build Status](https://travis-ci.org/Z2PackDev/bands_inspect.svg?branch=master)](https://travis-ci.org/Z2PackDev/bands_inspect)
